========================
Contributing to alphaCSC
========================

Pre-commit hook
===============

A pre-commit hook that will run lint checks (in particular flake8)
may be enabled. To do so, run

.. code::

    pip install pre-commit
    pre-commit install
